# pynterface

[![PyPi Version](https://badgen.net/pypi/v/pynterface/)](https://pypi.org/project/pynterface)
[![Documentation Status](https://readthedocs.org/projects/pynterface/badge/?version=latest)](https://pynterface.readthedocs.io/en/latest/?badge=latest)

A module to deal with terminal-based input and output! This package is available on PyPI [here](https://pypi.org/project/pynterface/).

## Why Use This?
This package has many features that helps make coding user inputs easier and terminal outputs more pretty. You can do many things with either regard, with one line!

## Installation 
To install, simply run the following:
```
$ pip install pynterface
```

Then, you can use it as you please!
```python
>>> import pynterface
```

## Documentation
Full documentation can be found on the [readthedocs](https://pynterface.readthedocs.io/en/latest/index.html) site for the module.

## Contribution
For adding features, pull requests are greatly appreciated. If you have an idea, please open an issue! Feel free to message me on my email singhvi.vivaan@gmail.com if you have any concerns!

## License
This project is released under the MIT license.
